;-- TIME_STAMP   2018-12-28 04:14:24   v 0.1

; #FUNCTION# ====================================================================================================================
; Name ..........: _ComputeCrc32
; Description ...: Calculates the CRC32 checksum of a file or a block of memory
; Syntax ........: _ComputeCrc32($vCheck)
; Parameters ....: $vCheck              - a variant value. A filename or pointer to the memory block to calculate the checksum.
; Return values .: Success: The CRC32 checksum (DWORD).
;                  Failure: 0 and sets the @error flag to non-zero.
; Author ........: Bitnugger
; Modified ......:
; Remarks .......: Not documented in MSDN
; Related .......: _WinAPI_ComputeCrc32
; Link ..........:
; Example .......: Yes
; ===============================================================================================================================
Func _ComputeCrc32($vCheck, $iLen = -1, $iCheck = 1) ; 1 = FileName, 2 = String
	Local $tData, $iLength, $hFile

	Switch True
		Case IsDllStruct($vCheck)
			$tData = $vCheck
			$iLength = DllStructGetSize($tData)
		Case IsPtr($vCheck)
			If $iLen < 1 Then Return SetError(10, @extended, 0)
			$iLength = $iLen
			$tData = $vCheck
		Case IsString($vCheck)
			If $iCheck = 1 And FileExists($vCheck) Then
				$hFile = FileOpen($vCheck, 16) ; $FO_BINARY (16)
				$vCheck = FileRead($hFile)
				$iLength = @extended
				FileClose($hFile)
			ElseIf $iCheck = 2 Then
				$iLength = StringLen($vCheck)
			Else
				Return SetError(80, @extended, 0)
			EndIf
		Case Else
			Return SetError(1, @error, 0)
	EndSwitch

	If $iLength = 0 Then Return SetError(30, @extended, 0)

	$tData = DllStructCreate('byte[' & $iLength & ']')
	DllStructSetData($tData, 1, $vCheck)

	Local $aRet = DllCall('ntdll.dll', 'dword', 'RtlComputeCrc32', 'dword', 0, 'struct*', $tData, 'int', $iLength)
	If @error Or Not $aRet[0] Then Return SetError(90, @extended, 0)

	Return '0x' & Hex($aRet[0])
EndFunc   ;==>_ComputeCrc32
